BASEDIR="/home/${USER}/gisdata/"
TMPDIR="${BASEDIR}/tmp"
UNZIPTOOL=unzip
WGETTOOL="/usr/bin/wget"
export PGBIN=/usr/pgsql-9.3/bin
PSQL="${PGBIN}/psql --dbname=geocoder --username=postgres"
SHP2PGSQL=${PGBIN}/shp2pgsql

cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/PLACE/tl_*_25_* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/PLACE
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_place.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_place(CONSTRAINT pk_MA_place PRIMARY KEY (plcidfp) ) INHERITS(place);"
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_25_place.dbf tiger_staging.ma_place | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.MA_place RENAME geoid TO plcidfp;SELECT loader_load_staged_data(lower('MA_place'), lower('MA_place')); ALTER TABLE tiger_data.MA_place ADD CONSTRAINT uidx_MA_place_gid UNIQUE (gid);"
${PSQL} -c "CREATE INDEX idx_MA_place_soundex_name ON tiger_data.MA_place USING btree (soundex(name));"
${PSQL} -c "CREATE INDEX tiger_data_MA_place_the_geom_gist ON tiger_data.MA_place USING gist(the_geom);"
${PSQL} -c "ALTER TABLE tiger_data.MA_place ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/COUSUB/tl_*_25_* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/COUSUB
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_cousub.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_cousub(CONSTRAINT pk_MA_cousub PRIMARY KEY (cosbidfp), CONSTRAINT uidx_MA_cousub_gid UNIQUE (gid)) INHERITS(cousub);"
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_25_cousub.dbf tiger_staging.ma_cousub | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.MA_cousub RENAME geoid TO cosbidfp;SELECT loader_load_staged_data(lower('MA_cousub'), lower('MA_cousub')); ALTER TABLE tiger_data.MA_cousub ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX tiger_data_MA_cousub_the_geom_gist ON tiger_data.MA_cousub USING gist(the_geom);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_cousub_countyfp ON tiger_data.MA_cousub USING btree(countyfp);"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/TRACT/tl_*_25_* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/TRACT
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_tract.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_tract(CONSTRAINT pk_MA_tract PRIMARY KEY (tract_id) ) INHERITS(tiger.tract); "
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_25_tract.dbf tiger_staging.ma_tract | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.MA_tract RENAME geoid TO tract_id;  SELECT loader_load_staged_data(lower('MA_tract'), lower('MA_tract')); "
${PSQL} -c "CREATE INDEX tiger_data_MA_tract_the_geom_gist ON tiger_data.MA_tract USING gist(the_geom);"
${PSQL} -c "VACUUM ANALYZE tiger_data.MA_tract;"
${PSQL} -c "ALTER TABLE tiger_data.MA_tract ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/TABBLOCK/tl_*_25_* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/TABBLOCK
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_tabblock.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_tabblock(CONSTRAINT pk_MA_tabblock PRIMARY KEY (tabblock_id)) INHERITS(tiger.tabblock);"
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_25_tabblock.dbf tiger_staging.ma_tabblock | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.MA_tabblock RENAME geoid TO tabblock_id;  SELECT loader_load_staged_data(lower('MA_tabblock'), lower('MA_tabblock'), '{gid, statefp10, countyfp10, tractce10, blockce10,suffix1ce,blockce,tractce}'::text[]); "
${PSQL} -c "ALTER TABLE tiger_data.MA_tabblock ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX tiger_data_MA_tabblock_the_geom_gist ON tiger_data.MA_tabblock USING gist(the_geom);"
${PSQL} -c "vacuum analyze tiger_data.MA_tabblock;"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/BG/tl_*_25_* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/BG
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_bg.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_bg(CONSTRAINT pk_MA_bg PRIMARY KEY (bg_id)) INHERITS(tiger.bg);"
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_25_bg.dbf tiger_staging.ma_bg | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.MA_bg RENAME geoid TO bg_id;  SELECT loader_load_staged_data(lower('MA_bg'), lower('MA_bg')); "
${PSQL} -c "ALTER TABLE tiger_data.MA_bg ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX tiger_data_MA_bg_the_geom_gist ON tiger_data.MA_bg USING gist(the_geom);"
${PSQL} -c "vacuum analyze tiger_data.MA_bg;"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2010/ZCTA5/2010/*_25* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2010/ZCTA5/2010
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_zcta510.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_zcta5(CONSTRAINT pk_MA_zcta5 PRIMARY KEY (zcta5ce,statefp), CONSTRAINT uidx_MA_zcta5_gid UNIQUE (gid)) INHERITS(zcta5);"
for z in *zcta510.dbf; do
${SHP2PGSQL}  -D -s 4269 -g the_geom -W "latin1" $z tiger_staging.MA_zcta510 | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('MA_zcta510'), lower('MA_zcta5'));"
done

${PSQL} -c "ALTER TABLE tiger_data.MA_zcta5 ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX tiger_data_MA_zcta5_the_geom_gist ON tiger_data.MA_zcta5 USING gist(the_geom);"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/FACES/*_25* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/FACES/
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_faces.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_faces(CONSTRAINT pk_MA_faces PRIMARY KEY (gid)) INHERITS(faces);"
for z in *faces.dbf; do
${SHP2PGSQL}  -D -s 4269 -g the_geom -W "latin1" $z tiger_staging.MA_faces | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('MA_faces'), lower('MA_faces'));"
done

${PSQL} -c "CREATE INDEX tiger_data_MA_faces_the_geom_gist ON tiger_data.MA_faces USING gist(the_geom);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_faces_tfid ON tiger_data.MA_faces USING btree (tfid);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_faces_countyfp ON tiger_data.MA_faces USING btree (countyfp);"
${PSQL} -c "ALTER TABLE tiger_data.MA_faces ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "vacuum analyze tiger_data.MA_faces;"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/FEATNAMES/*_25* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/FEATNAMES/
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_featnames.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_featnames(CONSTRAINT pk_MA_featnames PRIMARY KEY (gid)) INHERITS(featnames);ALTER TABLE tiger_data.MA_featnames ALTER COLUMN statefp SET DEFAULT '25';"
for z in *featnames.dbf; do
${SHP2PGSQL}  -D -s 4269 -g the_geom -W "latin1" $z tiger_staging.MA_featnames | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('MA_featnames'), lower('MA_featnames'));"
done

${PSQL} -c "CREATE INDEX idx_tiger_data_MA_featnames_snd_name ON tiger_data.MA_featnames USING btree (soundex(name));"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_featnames_lname ON tiger_data.MA_featnames USING btree (lower(name));"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_featnames_tlid_statefp ON tiger_data.MA_featnames USING btree (tlid,statefp);"
${PSQL} -c "ALTER TABLE tiger_data.MA_featnames ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "vacuum analyze tiger_data.MA_featnames;"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/EDGES/*_25* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/EDGES/
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_edges.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_edges(CONSTRAINT pk_MA_edges PRIMARY KEY (gid)) INHERITS(edges);"
for z in *edges.dbf; do
${SHP2PGSQL}  -D -s 4269 -g the_geom -W "latin1" $z tiger_staging.MA_edges | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('MA_edges'), lower('MA_edges'));"
done

${PSQL} -c "ALTER TABLE tiger_data.MA_edges ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_edges_tlid ON tiger_data.MA_edges USING btree (tlid);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_edgestfidr ON tiger_data.MA_edges USING btree (tfidr);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_edges_tfidl ON tiger_data.MA_edges USING btree (tfidl);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_edges_countyfp ON tiger_data.MA_edges USING btree (countyfp);"
${PSQL} -c "CREATE INDEX tiger_data_MA_edges_the_geom_gist ON tiger_data.MA_edges USING gist(the_geom);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_edges_zipl ON tiger_data.MA_edges USING btree (zipl);"
${PSQL} -c "CREATE TABLE tiger_data.MA_zip_state_loc(CONSTRAINT pk_MA_zip_state_loc PRIMARY KEY(zip,stusps,place)) INHERITS(zip_state_loc);"
${PSQL} -c "INSERT INTO tiger_data.MA_zip_state_loc(zip,stusps,statefp,place) SELECT DISTINCT e.zipl, 'MA', '25', p.name FROM tiger_data.MA_edges AS e INNER JOIN tiger_data.MA_faces AS f ON (e.tfidl = f.tfid OR e.tfidr = f.tfid) INNER JOIN tiger_data.MA_place As p ON(f.statefp = p.statefp AND f.placefp = p.placefp ) WHERE e.zipl IS NOT NULL;"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_zip_state_loc_place ON tiger_data.MA_zip_state_loc USING btree(soundex(place));"
${PSQL} -c "ALTER TABLE tiger_data.MA_zip_state_loc ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "vacuum analyze tiger_data.MA_edges;"
${PSQL} -c "vacuum analyze tiger_data.MA_zip_state_loc;"
${PSQL} -c "CREATE TABLE tiger_data.MA_zip_lookup_base(CONSTRAINT pk_MA_zip_state_loc_city PRIMARY KEY(zip,state, county, city, statefp)) INHERITS(zip_lookup_base);"
${PSQL} -c "INSERT INTO tiger_data.MA_zip_lookup_base(zip,state,county,city, statefp) SELECT DISTINCT e.zipl, 'MA', c.name,p.name,'25'  FROM tiger_data.MA_edges AS e INNER JOIN tiger.county As c  ON (e.countyfp = c.countyfp AND e.statefp = c.statefp AND e.statefp = '25') INNER JOIN tiger_data.MA_faces AS f ON (e.tfidl = f.tfid OR e.tfidr = f.tfid) INNER JOIN tiger_data.MA_place As p ON(f.statefp = p.statefp AND f.placefp = p.placefp ) WHERE e.zipl IS NOT NULL;"
${PSQL} -c "ALTER TABLE tiger_data.MA_zip_lookup_base ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_zip_lookup_base_citysnd ON tiger_data.MA_zip_lookup_base USING btree(soundex(city));"
cd ${BASEDIR}
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/ADDR/*_25* --no-parent --relative --recursive --level=2 --accept=zip --mirror --reject=html
cd ${BASEDIR}/ftp2.census.gov/geo/tiger/TIGER2013/ADDR/
rm -f ${TMPDIR}/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*_25*_addr.zip ; do $UNZIPTOOL -o -d $TMPDIR $z; done
cd $TMPDIR;

${PSQL} -c "CREATE TABLE tiger_data.MA_addr(CONSTRAINT pk_MA_addr PRIMARY KEY (gid)) INHERITS(addr);ALTER TABLE tiger_data.MA_addr ALTER COLUMN statefp SET DEFAULT '25';"
for z in *addr.dbf; do
${SHP2PGSQL}  -D -s 4269 -g the_geom -W "latin1" $z tiger_staging.MA_addr | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('MA_addr'), lower('MA_addr'));"
done

${PSQL} -c "ALTER TABLE tiger_data.MA_addr ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_addr_least_address ON tiger_data.MA_addr USING btree (least_hn(fromhn,tohn) );"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_addr_tlid_statefp ON tiger_data.MA_addr USING btree (tlid, statefp);"
${PSQL} -c "CREATE INDEX idx_tiger_data_MA_addr_zip ON tiger_data.MA_addr USING btree (zip);"
${PSQL} -c "CREATE TABLE tiger_data.MA_zip_state(CONSTRAINT pk_MA_zip_state PRIMARY KEY(zip,stusps)) INHERITS(zip_state); "
${PSQL} -c "INSERT INTO tiger_data.MA_zip_state(zip,stusps,statefp) SELECT DISTINCT zip, 'MA', '25' FROM tiger_data.MA_addr WHERE zip is not null;"
${PSQL} -c "ALTER TABLE tiger_data.MA_zip_state ADD CONSTRAINT chk_statefp CHECK (statefp = '25');"
${PSQL} -c "vacuum analyze tiger_data.MA_addr;"

